@@ -4,20 +4,20 @@
 
 package Ttl::Un;
 use Moose;
-extends 'Reflex::Object';
-use Reflex::Trait::Emitter;
+extends 'Reflex::Base';
+use Reflex::Trait::EmitsOnChange;
 
 has in => (
 	isa     => 'Bool',
 	is      => 'rw',
-	traits  => ['Reflex::Trait::Emitter'],
+	traits  => ['Reflex::Trait::EmitsOnChange'],
 	event   => 'change',
 );
 
 has out => (
 	isa     => 'Bool',
 	is      => 'rw',
-	traits  => ['Reflex::Trait::Emitter'],
+	traits  => ['Reflex::Trait::EmitsOnChange'],
 );
 
 1;
