@@ -1,6 +1,6 @@
 package Reflex;
 BEGIN {
-  $Reflex::VERSION = '0.055';
+  $Reflex::VERSION = '0.056';
 }
 
 use warnings;
@@ -47,7 +47,7 @@ Reflex - Class library for flexible, reactive programs.
 
 =head1 VERSION
 
-version 0.055
+version 0.056
 
 =head1 SYNOPSIS
 
@@ -358,12 +358,17 @@ Miscellaneous helper functions.
 
 =head1 ASSISTANCE
 
+Thank you for volunteering to assist with this project.  You can find
+like-minded people in a few places, in descending order of preference.
+Or, oh, wait, maybe you wanted assistance using it?  We'll help you,
+too. :)
+
 See irc.perl.org #reflex for help with Reflex.
 
-See irc.perl.org #moose for help with Moose.
-
 See irc.perl.org #poe for help with POE and Reflex.
 
+See irc.perl.org #moose for help with Moose.
+
 Support is officially available from POE's mailing list as well.  Send
 a blank message to
 L<poe-subscribe@perl.org|mailto:poe-subscribe@perl.org>
@@ -386,9 +391,9 @@ lengthy and sometimes irrelevant design discussion for oh so long.
 
 L<Moose>, L<POE>, the Reflex namespace on CPAN.
 
-TODO - Set up ohlo.
+Ohlo - https://www.ohloh.net/p/reflex-perl
 
-TODO - Set up CIA.
+CIA - http://cia.vc/stats/project/reflex
 
 TODO - Set up home page.
 
